#!/usr/bin/sh

#ident	"%W%"

#
# The source files here are entirely from:
#
#	ESP Ghostscript 7.05.6 distribution from http://www.cups.org/
#
# execpt for the following files:
#
# - espgs-7.05.6.sh		(build script)
# - espgs-7.05.6.depend		(depend file for top-level build script)
# - espgs-7.05.6-unixware.patch	(patch file for UnixWare port)
# - ijs/ijs-0.34.sh		(ijs build script)
# - ijs/ijs-0.34-unixware.patch	(ijs patch file)
#
# The font files (in fonts directory) are entirely from:
#
#	gnu-gs-fonts-[std,other]-6.0 distribution
#

set -x
set -e

#
# Apply patches.
#
for patch in espgs-7.05.6-unixware.patch 
do
	[ -f .${patch}.applied ] || {
		/bin/patch -c -p0 -i ${patch}
		/bin/date > .${patch}.applied
	}
done

#
# Create link to jpeg source.
# Ghostscript compiles jpeg with non-standard flags to support old PS files.
#
if [ ! -d '../jpeg-6b' ]
then
	echo "ERROR: ../jpeg-6b not found" >&2
	exit 1
fi
/bin/rm -f './jpeg'
/bin/ln -s '../jpeg-6b' './jpeg' 2>/dev/null

#
# Do not create links to zlib and libpng source -- use shared libs in xenv.
#
# rm -f zlib; /bin/ln -s ../zlib-1.1 ./zlib 2>/dev/null
# rm -f libpng; /bin/ln -s ../libpng-1.2.5 ./libpng 2>/dev/null

#
# Define directory pathnames
#
GS_DIR=/usr/share/ghostscript
GS_FONTDIR=${GS_DIR}/fonts
GS_LIBDIR=${GS_DIR}/7.05/lib
GS_DOCDIR=${GS_DIR}/7.05/doc

CUPS_DIR=/usr/share/cups
CUPS_FONTDIR=${CUPS_DIR}/fonts

#
# Configure with options tailored for UnixWare.
#
./configure \
	--host=i686 \
	--prefix=/usr \
	--with-fontpath=${CUPS_FONTDIR} \
	--with-ijs \
	--without-gimp-print \
	--without-omni \
	--with-x \
	--x-includes=${TOOLS}/usr/X11R6.1/include \
	--x-libraries=${TOOLS}/usr/X11R6.1/lib

#
# Create obj/ and bin/ directories otherwise make will fail.
#
[ ! -d obj ] && /bin/mkdir obj
[ ! -d bin ] && /bin/mkdir bin

#
# Make and install in ${ROOT}/${MACH}.
#
# Redefine CP_ to prevent re-build failure.
#
# Redefine EXTRALIBS.
# + configure adds extra libraries (jpeg, slp, ssl, crypto etc.)
# + link libcups and libcupsimage statically so that gs is independent of cups.
#
# Redefine XLIBS
# + configure does not add libSM and libICE. (Note -l is added by Makefile.)
#
# Define install_prefix -- it is used by cups.mak.
#
# Define GS_DOCDIR and GS_LIB_DEFAULT.
# + These pathnames are hardcoded in gs binary and
#   Makefile adds ${ROOT}/${MACH} to these variables.
#
${MAKE} \
	CP_="cp -f" \
	EXTRALIBS="-Bstatic -lcups -lcupsimage -Bdynamic -lsocket" \
	XLIBS="Xt Xext SM ICE X11" \
	prefix=${ROOT}/${MACH}/usr \
	install_prefix=${ROOT}/${MACH} \
	man1ext=".1" \
	GS_DOCDIR=${GS_DOCDIR} \
	GS_LIB_DEFAULT=${GS_LIBDIR}:${GS_FONTDIR}:${CUPS_FONTDIR} \
	install

#
# Install GNU Ghostscript 6.0 fonts.  The fonts directory has both
# gnu-gs-fonts-std-6.0 and gnu-gs-fonts-other-6.0 fonts.
#
[ ! -d ${ROOT}/${MACH}/${GS_FONTDIR} ] &&
	/bin/mkdir -p ${ROOT}/${MACH}/${GS_FONTDIR}

/bin/ls fonts | /bin/xargs -i /bin/cp -f fonts/{} ${ROOT}/${MACH}/${GS_FONTDIR}

#
# Install Docview metadata file.
#
DS_group=/usr/share/meta/doc/HelpTopics/DSKhome/DSKgroup

[ ! -d ${ROOT}/${MACH}/${DS_group} ] &&
	/bin/mkdir -p ${ROOT}/${MACH}/${DS_group}

/bin/cat > ${ROOT}/${MACH}/${DS_group}/DSK_gs.desktop << EOF
[Desktop entry]
Name=Ghostscript PS/PDF Interpreter and Viewer
DocPath=${GS_DOCDIR}/index.html
EOF

#
# Ghostscript (by default) does not build and install IJS library and header
# files.  We build them now.
#
cd ijs
/bin/sh ijs-0.34.sh
